import ajax from "@/utils/request.js";
import ajaxAxios from "@/utils/request_axios.js";

/**
 * 广告
 * @returns {AxjxPromise}
 */
export function advertisementApi(data) {
  return ajax({
    url: "/kuyun_eye_ad/cbd_public/perform",
    method: "get",
    data,
  });
}
/**
 * 流入流出
 * @returns {AxjxPromise}
 */
export function inOutApi(data) {
  return ajax({
    url: "/api/recent_inout",
    method: "get",
    data,
  });
}
/**
 * epg
 * @returns {AxjxPromise}
 */
export function epgApi(data) {
  return ajax({
    url: "/api/recent_epgs",
    method: "get",
    data,
  });
}
/**
 * 直播实时 分
 * @returns {AxjxPromise}
 */
export function liveRealDataMinApi(data) {
  return ajax({
    url: "/api/sec_ratings",
    method: "get",
    data,
  });
}
/**
 * 直播实时数据
 * @returns {AxjxPromise}
 */
export function liveRealDataApi(data) {
  return ajax({
    url: "/api/min_ratings",
    method: "get",
    data,
  });
}
/**
 * 直播实时数据
 * @returns {AxjxPromise}
 */
export function liveDataApi(data) {
  return ajax({
    url: "/api/tvlb",
    method: "get",
    data,
  });
}
/**
 * 高光数据
 * @returns {AxjxPromise}
 */
export function heightlightDataApi(data) {
  return ajax({
    url: "/api/hl/calendar",
    method: "get",
    data,
  });
}
/**
 * 高光时刻
 * @returns {AxjxPromise}
 */
export function heightlightApi(data) {
  return ajax({
    url: "/api/hl/list-milestone",
    method: "get",
    data,
  });
}
/**
 * 节目
 * @returns {AxjxPromise}
 */
export function list(data) {
  return ajax({
    url: "/api/proepglb",
    method: "get",
    data,
  });
}
/**
 * 节目导出
 * @returns {AxjxPromise}
 */
export function listcsv(data) {
  return ajax({
    url: "/api/proepglb/csv",
    method: "get",
    downCsv: true,
    data,
  });
}
/**
 * 频道
 * @returns {AxjxPromise}
 */
export function channel(data) {
  return ajax({
    url: "/api/protvlb",
    method: "get",
    data,
  });
}
/**
 * 频道导出
 * @returns {AxjxPromise}
 */
export function channelcsv(data) {
  return ajax({
    url: "/api/protvlb/csv",
    method: "get",
    downCsv: true,
    data,
  });
}

/**
 * 获取精品节目列表
 * @props {}
 * @returns {AxjxPromise}
 */
export function epgList() {
  return ajax({
    urlType: "url2",
    url: "/program",
    method: "get",
  });
}
/**
 * 获取精品节目详情
 * @props {}
 * @returns {AxjxPromise}
 */
export function epgDetail(data) {
  return ajax({
    urlType: "url2",
    url: "/epg-detail",
    method: "get",
    target: data.target,
    data: { epgId: data.epgId },
  });
}
/**
 * 获取精品节目指标
 * @props {}
 * @returns {AxjxPromise}
 */
export function epgResult(data) {
  return ajax({
    urlType: "url2",
    url: "/epg-result",
    method: "get",
    data,
  });
}

/**
 * 自由接口
 * @props {url, data}
 * @return {AxjxPromise}
 */
export function defaultAjax(props) {
  return ajax({
    urlType: "url3",
    url: props.url,
    method: "get",
    notLoad: props.notLoad,
    target: props.target,
    data: props.data,
  });
}

/**
 * 频率列表
 * @props {}
 * @return {AxjxPromise}
 */
export function frequencyList() {
  return ajax({
    urlType: "url2",
    url: "/broadcast/dict",
    method: "get",
  });
}
/**
 * 频率查询
 * @props {}
 * @return {AxjxPromise}
 */
export function PLList(data) {
  return ajax({
    urlType: "url2",
    url: "/broadcast/list",
    method: "get",
    data,
  });
}

// 全国接口

/**
 * 频道全天节目
 * 表格查询
 * @props {}
 * @return {AxjxPromise}
 */
export function allDayEpg(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/broadcast/list",
    method: "get",
    data,
  });
}
// 重叠度

/**
 * 节目查询
 * 图表查询
 * @props {}
 * @return {AxjxPromise}
 */
export function overlapSearchTitle(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/search_suggest?" + data,
    method: "GET",
  });
}
/**
 * 节目重叠度
 * 图表查询
 * @props {}
 * @return {AxjxPromise}
 */
export function overlap(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/ProUserOverlapAction",
    method: "GET",
    data,
  });
}

/**
 * 广告频道列表
 * @props {}
 * @return {AxjxPromise}
 */
export function adChannelList() {
  return ajax({
    urlType: "adAPI",
    url: "/ad/channel",
    method: "GET",
  });
}

/**
 * 投放分析
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function launchList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/day",
    method: "POST",
    data,
  });
}

/**
 * 时段分析
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function trendList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/hour",
    method: "POST",
    data,
  });
}

/**
 * 行业占比
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function proportionList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/ratio",
    method: "POST",
    data,
  });
}

/**
 * 客户投放详情
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function customerList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/detail",
    method: "POST",
    data,
  });
}

/**
 * 优势客户
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function advantageousList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/youshi",
    method: "POST",
    data,
  });
}

/**
 * 潜在客户
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function potentialList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/qianzai",
    method: "POST",
    data,
  });
}

/**
 * 饱和度
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function saturationList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/saturation",
    method: "POST",
    data,
  });
}

/**
 * 行业列表
 * @return {AxjxPromise}
 */
export function allindustryList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/list",
    method: "GET",
    data,
  });
}

/**
 * 全行业
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function industryList(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/market",
    method: "POST",
    data,
  });
}

/***************************************分行业 */

/**
 * 分行业硬广
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function byIndustryTrendHard(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/TrendHard",
    method: "POST",
    data,
  });
}
/**
 * 分行业软广
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function byIndustryTrendSoft(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/TrendSoft",
    method: "POST",
    data,
  });
}

/**
 * 中小行业占比
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function smallIndustryProportion(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/MSIndustryProportion",
    method: "POST",
    data,
  });
}

/**
 * 媒体份额
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function MediaShare(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/MediaShare",
    method: "POST",
    data,
  });
}

/**
 * 频道份额
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ChannelDistribution(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/ChannelDistribution",
    method: "POST",
    data,
  });
}

/**
 * 节目类型
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ProgramTypeDistribution(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/ProgramTypeDistribution",
    method: "POST",
    data,
  });
}

/**
 * 节目类型
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ProgramTypeDistributionChart(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/ProgramTypeDistributionTable",
    method: "POST",
    data,
  });
}

/**
 * 重点客户
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ImportantCustomer(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/ImportantCustomer",
    method: "POST",
    data,
  });
}

/**
 * 周走势
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function LastWeekTrend(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/industry/LastWeekTrend",
    method: "POST",
    data,
  });
}

/**
 * 品牌top
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function BrandTop(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/index/brand",
    method: "POST",
    data,
  });
}

/**
 * 品牌top
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ChannelTop(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/index/channel",
    method: "POST",
    data,
  });
}

/**
 * 投放分析
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function channelRank(data) {
  return ajax({
    urlType: "adAPI",
    url: "/ad/channel/rank",
    method: "POST",
    data,
  });
}

/**
 * 获取平台信息数据
 * @props {string} end
 * @return {AxjxPromise}
 */
export function platform(data) {
  return ajax({
    urlType: "url2",
    url: "/new-media/agg",
    method: "POST",
    data,
  });
}

/**
 * 获取平台信息数据
 * @props {string} end
 * @return {AxjxPromise}
 */
export function platformlistData(data) {
  return ajax({
    urlType: "url2",
    url: "/new-media/list",
    method: "POST",
    data,
  });
}

/**
 * 获取平台信息列表
 * @props {string} end
 * @return {AxjxPromise}
 */
export function platformList(data) {
  return ajax({
    urlType: "url2",
    url: "/new-media/platform",
    method: "POST",
    data,
  });
}

/**
 * 归集登录
 * @return {AxjxPromise}
 */
export function guijiLogin(data) {
  return ajaxAxios({
    url: "/login-v2",
    method: "POST",
    data,
  });
}

/**
 * 归集活动接口
 * @return {AxjxPromise}
 */
export function guijiActivity(data) {
  return ajaxAxios({
    url: "/activity/list",
    method: "POST",
    data,
  });
}

/**
 * 归集话题
 * @props {string} activityId
 * @return {AxjxPromise}
 */
export function guijiTopic(data) {
  return ajaxAxios({
    url: "/topic/list",
    method: "POST",
    data,
  });
}

/**
 * 传播数据
 * @props {string} topic
 * @return {AxjxPromise}
 */
export function guijiSpread(data) {
  return ajaxAxios({
    url: "/topic/overview?topic=" + data.topic,
    method: "GET",
  });
}

/**
 * 传播量趋势
 * @props {string} topic
 * @return {AxjxPromise}
 */
export function guijiTrend(data) {
  return ajaxAxios({
    url: "/topic/history?topic=" + data.topic,
    method: "GET",
  });
}

/**
 * 部门传播量排行
 * @props {string} depRange
 * @props {string} title
 * @return {AxjxPromise}
 */
export function guijiDepartment(data) {
  return ajaxAxios({
    url: "/topic/read",
    method: "POST",
    data
  });
}

/**
 * 热点报道
 * @props {string} topic
 * @return {AxjxPromise}
 */
export function guijiHottopic(data) {
  return ajaxAxios({
    url: "/charts/hot-topic?topic=" + data.topic,
    method: "GET",
  });
}

/**
 * 部门列表
 * @return {AxjxPromise}
 */
export function guijiBumenList() {
  return ajaxAxios({
    url: "/topic/dep-dict",
    method: "GET",
  });
}

/**
 * 发稿统计
 * @return {AxjxPromise}
 */
export function guijiFagao(data) {
    console.log(data)
  return ajaxAxios({
    url: "/topic/detail",
    method: "POST",
    data
  });
}

/**
 * 发稿统计
 * @return {AxjxPromise}
 */
export function leverAudience(data) {
    console.log(data)
  return ajax({
    urlType: "leverAudience",
    url: "/cxzx-program/flow/channels",
    method: "GET",
    data
  });
}
